@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Duadua::Parser;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 my @PARSER_PROC_LIST = qw/
     Duadua::Parser::Browser::MicrosoftEdge
@@ -41,6 +41,7 @@ my @PARSER_PROC_LIST = qw/
     Duadua::Parser::Bot::Msnbot
     Duadua::Parser::Bot::BotMisc
 
+    Duadua::Parser::Browser::SamsungInternetBrowser
     Duadua::Parser::Browser::Yandex
     Duadua::Parser::Browser::DuckDuckGo
     Duadua::Parser::Bot::OracleGrapeshotCrawler
@@ -56,6 +57,9 @@ my @PARSER_PROC_LIST = qw/
     Duadua::Parser::Bot::Inoreader
     Duadua::Parser::Bot::Fastladder
     Duadua::Parser::Bot::Feedeen
+    Duadua::Parser::Bot::Feedspot
+    Duadua::Parser::Bot::OldReader
+
     Duadua::Parser::Browser::Xiaomi
     Duadua::Parser::FeaturePhone::FeaturePhone
     Duadua::Parser::Bot::Netcraft
@@ -321,7 +325,7 @@ The list of User Agent Parser
 
 =begin html
 
-<a href="https://github.com/bayashi/Duadua/blob/master/lib/Duadua.pm"><img src="https://img.shields.io/badge/Version-0.16-green?style=flat"></a> <a href="https://github.com/bayashi/Duadua/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png?style=flat"></a> <a href="https://github.com/bayashi/Duadua/actions"><img src="https://github.com/bayashi/Duadua/workflows/master/badge.svg?_t=1584226101"/></a> <a href="https://coveralls.io/r/bayashi/Duadua"><img src="https://coveralls.io/repos/bayashi/Duadua/badge.png?_t=1584226101&branch=master"/></a>
+<a href="https://github.com/bayashi/Duadua/blob/master/lib/Duadua.pm"><img src="https://img.shields.io/badge/Version-0.17-green?style=flat"></a> <a href="https://github.com/bayashi/Duadua/blob/master/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png?style=flat"></a> <a href="https://github.com/bayashi/Duadua/actions"><img src="https://github.com/bayashi/Duadua/workflows/master/badge.svg?_t=1584976739"/></a> <a href="https://coveralls.io/r/bayashi/Duadua"><img src="https://coveralls.io/repos/bayashi/Duadua/badge.png?_t=1584976739&branch=master"/></a>
 
 =end html
 
