@@ -98,6 +98,45 @@ sub try {
 
         $h = Duadua::Util->set_os($d, $h);
     }
+    elsif ( index($d->ua, ' zgrab/') > -1 ) {
+        $h = {
+            name   => 'ZGrab',
+            is_bot => 1,
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m! zgrab/([\d.x]+)!);
+            $h->{version} = $version if $version;
+        }
+
+        $h = Duadua::Util->set_os($d, $h);
+    }
+    elsif ( index($d->ua, ' RyowlEngine/') > -1 ) {
+        $h = {
+            name   => 'RyowlEngine',
+            is_bot => 1,
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m! RyowlEngine/([\d.]+)!);
+            $h->{version} = $version if $version;
+        }
+
+        $h = Duadua::Util->set_os($d, $h);
+    }
+    elsif ( index($d->ua, ' DataXu/') > -1 ) {
+        $h = {
+            name   => 'DataXu',
+            is_bot => 1,
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m! DataXu/([\d.]+)!);
+            $h->{version} = $version if $version;
+        }
+
+        $h = Duadua::Util->set_os($d, $h);
+    }
 
     return $h;
 }
